==> jc-1.4.0.tar.gz: java/nio/charset/CoderResult__242.c <==
// final class java.nio.charset.CoderResult$2

// class file dependencies
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class 67d265e617bbfda5 java_nio_charset_CoderResult
// @dep_class e128648a7063a6bd java_nio_charset_CoderResult__242
// @dep_class 14254178dbad6381 java_nio_charset_CoderResult__24Cache
// @dep_class d7cd853200c3e71f java_util_HashMap

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_nio_charset_CoderResult
// @dep_header java_nio_charset_CoderResult__242
// @dep_header java_util_HashMap

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/nio/charset/CoderResult.h"
#include "java/nio/charset/CoderResult__242.h"
#include "java/util/HashMap.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// void <init>()
//

static _jc_linenum _jc_java_nio_charset_CoderResult__242$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_java_nio_charset_CoderResult__242$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_java_nio_charset_CoderResult__242$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_java_nio_charset_CoderResult__242$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_java_nio_charset_CoderResult__242$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		0,
	.function=		&_jc_java_nio_charset_CoderResult__242$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_nio_charset_CoderResult__242$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_nio_charset_CoderResult__242, _init$52f4ad9f2989aeee);

void
_jc_java_nio_charset_CoderResult__242$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_java_nio_charset_CoderResult__242$object *this)
{
	struct _jc_java_nio_charset_CoderResult__242$object *r0;
	struct _jc_java_util_HashMap$object *r1;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	r1 = _JC_NEW(env, java_util_HashMap);
	_JC_INVOKE_NONVIRTUAL(env, java_util_HashMap, _init$7cb044ce4fb0ada8, 0, r1, 11, _JC_FCONST(0x3f, 0x40, 0x0, 0x0));
	_JC_REF_FIELD(env, r0, java_nio_charset_CoderResult__24Cache, cache) = r1;
	_JC_LINE_NUMBER(75);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// protected final java.nio.charset.CoderResult make(int)
//

static _jc_linenum _jc_java_nio_charset_CoderResult__242$linenum_table$make$f3cbfffb1f7afd3c[];

static const unsigned char _jc_java_nio_charset_CoderResult__242$param_ptypes$make$f3cbfffb1f7afd3c[] = { 
_JC_TYPE_INT, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_java_nio_charset_CoderResult__242$param_types$make$f3cbfffb1f7afd3c[] = {
	&_jc_int$prim$type
};

_jc_method _jc_java_nio_charset_CoderResult__242$method_info$make$f3cbfffb1f7afd3c = {
	.name=			"make",
	.signature=		"(I)Ljava/nio/charset/CoderResult;",
	.class=			&_jc_java_nio_charset_CoderResult__242$type,
	.param_types=		&_jc_java_nio_charset_CoderResult__242$param_types$make$f3cbfffb1f7afd3c,
	.return_type=		&_jc_java_nio_charset_CoderResult$type,
	.param_ptypes=		&_jc_java_nio_charset_CoderResult__242$param_ptypes$make$f3cbfffb1f7afd3c,
	.signature_hash=	_JC_JLONG(0xf3cbfffb1f7afd3c),
	.access_flags=		_JC_ACC_PROTECTED|_JC_ACC_FINAL,
	.function=		&_jc_java_nio_charset_CoderResult__242$method$make$f3cbfffb1f7afd3c,
	.vtable_index=		_JC_OFFSETOF(struct _jc_java_nio_charset_CoderResult__242$vtable, java_nio_charset_CoderResult__242.make$f3cbfffb1f7afd3c) / sizeof(void *),
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_nio_charset_CoderResult__242$linenum_table$make$f3cbfffb1f7afd3c
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_nio_charset_CoderResult__242, make$f3cbfffb1f7afd3c);

_jc_java_nio_charset_CoderResult$object *
_jc_java_nio_charset_CoderResult__242$method$make$f3cbfffb1f7afd3c(_jc_env *const env, _jc_java_nio_charset_CoderResult__242$object *this, jint param0)
{
	jint i0;
	struct _jc_java_nio_charset_CoderResult__242$object *r0;
	struct _jc_java_nio_charset_CoderResult$object *r1;

	r0 = this;
	i0 = param0;
	_JC_LINE_NUMBER(78);				// 0
	r1 = _JC_NEW(env, java_nio_charset_CoderResult);
	_JC_PRIM_FIELD(env, r1, java_nio_charset_CoderResult, type) = 3;
	_JC_PRIM_FIELD(env, r1, java_nio_charset_CoderResult, length) = i0;
	return r1;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_java_nio_charset_CoderResult__242$methods[] = {
	&_jc_java_nio_charset_CoderResult__242$method_info$_init$52f4ad9f2989aeee,
	&_jc_java_nio_charset_CoderResult__242$method_info$make$f3cbfffb1f7afd3c
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_java_nio_charset_CoderResult__242$instanceof_hash_bucket_1[] = {
	&_jc_java_nio_charset_CoderResult__24Cache$type,
	_JC_NULL
};
static _jc_type *const _jc_java_nio_charset_CoderResult__242$instanceof_hash_bucket_61[] = {
	&_jc_java_nio_charset_CoderResult__242$type,
	_JC_NULL
};
static _jc_type *const _jc_java_nio_charset_CoderResult__242$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_java_nio_charset_CoderResult__242$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[1]=	_jc_java_nio_charset_CoderResult__242$instanceof_hash_bucket_1,
	[61]=	_jc_java_nio_charset_CoderResult__242$instanceof_hash_bucket_61,
	[113]=	_jc_java_nio_charset_CoderResult__242$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_java_nio_charset_CoderResult__242$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "java/nio/charset/CoderResult",	_JC_JLONG(0x67d265e617bbfda5) },
	{ "java/nio/charset/CoderResult$Cache",	_JC_JLONG(0x14254178dbad6381) },
	{ "java/util/HashMap",	_JC_JLONG(0xd7cd853200c3e71f) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_java_nio_charset_CoderResult__242$vtype _jc_java_nio_charset_CoderResult__242$type = {
    .type= {
	.name=			"java/nio/charset/CoderResult$2",
	.superclass=		&_jc_java_nio_charset_CoderResult__24Cache$type,
	.access_flags=		_JC_ACC_FINAL,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		14,
		.hash=			_JC_JLONG(0xe128648a7063a6bd),
		.source_file=		"CoderResult.java",
		.instance_size=		sizeof(_jc_java_nio_charset_CoderResult__242$refs) + sizeof(_jc_java_nio_charset_CoderResult__242$object),
		.num_virtual_refs=	1,
		.num_methods=		sizeof(_jc_java_nio_charset_CoderResult__242$methods) / sizeof(*_jc_java_nio_charset_CoderResult__242$methods),
		.methods=		_jc_java_nio_charset_CoderResult__242$methods,
		.instanceof_hash_table=	_jc_java_nio_charset_CoderResult__242$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_java_nio_charset_CoderResult__242$class_depends) / sizeof(*_jc_java_nio_charset_CoderResult__242$class_depends),
		.class_depends=		_jc_java_nio_charset_CoderResult__242$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.java_nio_charset_CoderResult__24Cache= {
	    .get$edc027d4a510997f=
		&_jc_java_nio_charset_CoderResult__24Cache$method$get$edc027d4a510997f,
	    .make$f3cbfffb1f7afd3c=				// overridden
		&_jc_java_nio_charset_CoderResult__242$method$make$f3cbfffb1f7afd3c,
	},
	.java_nio_charset_CoderResult__242= {
	    .make$f3cbfffb1f7afd3c=
		&_jc_java_nio_charset_CoderResult__242$method$make$f3cbfffb1f7afd3c,
	},
    }
};

==> jc-1.4.5.tar.gz: java/nio/charset/CoderResult__242.c <==
// final class java.nio.charset.CoderResult$2

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class 67d265e617bbfda5 java_nio_charset_CoderResult
// @dep_class e128648a7063a6bd java_nio_charset_CoderResult__242
// @dep_class 14254178dbad6381 java_nio_charset_CoderResult__24Cache
// @dep_class d7cd853200c3e71f java_util_HashMap

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_nio_charset_CoderResult
// @dep_header java_nio_charset_CoderResult__242
// @dep_header java_util_HashMap

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/nio/charset/CoderResult.h"
#include "java/nio/charset/CoderResult__242.h"
#include "java/util/HashMap.h"

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// void <init>()
//

static _jc_linenum _jc_java_nio_charset_CoderResult__242$linenum_table$_init$52f4ad9f2989aeee[];

static const unsigned char _jc_java_nio_charset_CoderResult__242$param_ptypes$_init$52f4ad9f2989aeee[] = { 
_JC_TYPE_VOID };

_jc_method _jc_java_nio_charset_CoderResult__242$method_info$_init$52f4ad9f2989aeee = {
	.name=			"<init>",
	.signature=		"()V",
	.class=			&_jc_java_nio_charset_CoderResult__242$type,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_java_nio_charset_CoderResult__242$param_ptypes$_init$52f4ad9f2989aeee,
	.signature_hash=	_JC_JLONG(0x52f4ad9f2989aeee),
	.access_flags=		0,
	.function=		&_jc_java_nio_charset_CoderResult__242$method$_init$52f4ad9f2989aeee,
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_nio_charset_CoderResult__242$linenum_table$_init$52f4ad9f2989aeee
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_nio_charset_CoderResult__242, _init$52f4ad9f2989aeee);

void _JC_JCNI_ATTR
_jc_java_nio_charset_CoderResult__242$method$_init$52f4ad9f2989aeee(_jc_env *const env, _jc_java_nio_charset_CoderResult__242$object *this)
{
	struct _jc_java_nio_charset_CoderResult__242$object *r0;
	struct _jc_java_util_HashMap$object *r1;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	r1 = _JC_NEW(env, java_util_HashMap);
	_JC_INVOKE_NONVIRTUAL(env, java_util_HashMap, _init$7cb044ce4fb0ada8, 0, r1, 11, _JC_FCONST(0x3f, 0x40, 0x0, 0x0));
	_JC_REF_FIELD(env, r0, java_nio_charset_CoderResult__24Cache, cache) = r1;
	_JC_LINE_NUMBER(75);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// protected final java.nio.charset.CoderResult make(int)
//

static _jc_linenum _jc_java_nio_charset_CoderResult__242$linenum_table$make$f3cbfffb1f7afd3c[];

static const unsigned char _jc_java_nio_charset_CoderResult__242$param_ptypes$make$f3cbfffb1f7afd3c[] = { 
_JC_TYPE_INT, _JC_TYPE_REFERENCE };

static _jc_type *const _jc_java_nio_charset_CoderResult__242$param_types$make$f3cbfffb1f7afd3c[] = {
	&_jc_int$prim$type
};

_jc_method _jc_java_nio_charset_CoderResult__242$method_info$make$f3cbfffb1f7afd3c = {
	.name=			"make",
	.signature=		"(I)Ljava/nio/charset/CoderResult;",
	.class=			&_jc_java_nio_charset_CoderResult__242$type,
	.param_types=		&_jc_java_nio_charset_CoderResult__242$param_types$make$f3cbfffb1f7afd3c,
	.return_type=		&_jc_java_nio_charset_CoderResult$type,
	.param_ptypes=		&_jc_java_nio_charset_CoderResult__242$param_ptypes$make$f3cbfffb1f7afd3c,
	.signature_hash=	_JC_JLONG(0xf3cbfffb1f7afd3c),
	.access_flags=		_JC_ACC_PROTECTED|_JC_ACC_FINAL,
	.function=		&_jc_java_nio_charset_CoderResult__242$method$make$f3cbfffb1f7afd3c,
	.vtable_index=		_JC_OFFSETOF(struct _jc_java_nio_charset_CoderResult__242$vtable, java_nio_charset_CoderResult__242.make$f3cbfffb1f7afd3c) / sizeof(void *),
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_nio_charset_CoderResult__242$linenum_table$make$f3cbfffb1f7afd3c
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_nio_charset_CoderResult__242, make$f3cbfffb1f7afd3c);

_jc_java_nio_charset_CoderResult$object * _JC_JCNI_ATTR
_jc_java_nio_charset_CoderResult__242$method$make$f3cbfffb1f7afd3c(_jc_env *const env, _jc_java_nio_charset_CoderResult__242$object *this, jint param0)
{
	jint i0;
	struct _jc_java_nio_charset_CoderResult__242$object *r0;
	struct _jc_java_nio_charset_CoderResult$object *r1;

	r0 = this;
	i0 = param0;
	_JC_LINE_NUMBER(78);				// 0
	r1 = _JC_NEW(env, java_nio_charset_CoderResult);
	_JC_PRIM_FIELD(env, r1, java_nio_charset_CoderResult, type) = 3;
	_JC_PRIM_FIELD(env, r1, java_nio_charset_CoderResult, length) = i0;
	return r1;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_java_nio_charset_CoderResult__242$methods[] = {
	&_jc_java_nio_charset_CoderResult__242$method_info$_init$52f4ad9f2989aeee,
	&_jc_java_nio_charset_CoderResult__242$method_info$make$f3cbfffb1f7afd3c
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_java_nio_charset_CoderResult__242$instanceof_hash_bucket_1[] = {
	&_jc_java_nio_charset_CoderResult__24Cache$type,
	_JC_NULL
};
static _jc_type *const _jc_java_nio_charset_CoderResult__242$instanceof_hash_bucket_61[] = {
	&_jc_java_nio_charset_CoderResult__242$type,
	_JC_NULL
};
static _jc_type *const _jc_java_nio_charset_CoderResult__242$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_java_nio_charset_CoderResult__242$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[1]=	_jc_java_nio_charset_CoderResult__242$instanceof_hash_bucket_1,
	[61]=	_jc_java_nio_charset_CoderResult__242$instanceof_hash_bucket_61,
	[101]=	_jc_java_nio_charset_CoderResult__242$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_java_nio_charset_CoderResult__242$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "java/nio/charset/CoderResult",	_JC_JLONG(0x67d265e617bbfda5) },
	{ "java/nio/charset/CoderResult$Cache",	_JC_JLONG(0x14254178dbad6381) },
	{ "java/util/HashMap",	_JC_JLONG(0xd7cd853200c3e71f) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_java_nio_charset_CoderResult__242$vtype _jc_java_nio_charset_CoderResult__242$type = {
    .type= {
	.name=			"java/nio/charset/CoderResult$2",
	.superclass=		&_jc_java_nio_charset_CoderResult__24Cache$type,
	.access_flags=		_JC_ACC_FINAL,
	.flags=			_JC_TYPE_REFERENCE,
	.imethod_hash_table=	_jc_empty_imethod_table,
	.imethod_quick_table=	_jc_empty_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		14,
		.hash=			_JC_JLONG(0xe128648a7063a6bd),
		.source_file=		"CoderResult.java",
		.instance_size=		sizeof(_jc_java_nio_charset_CoderResult__242$refs) + sizeof(_jc_java_nio_charset_CoderResult__242$object),
		.num_virtual_refs=	1,
		.num_methods=		sizeof(_jc_java_nio_charset_CoderResult__242$methods) / sizeof(*_jc_java_nio_charset_CoderResult__242$methods),
		.methods=		_jc_java_nio_charset_CoderResult__242$methods,
		.instanceof_hash_table=	_jc_java_nio_charset_CoderResult__242$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_java_nio_charset_CoderResult__242$class_depends) / sizeof(*_jc_java_nio_charset_CoderResult__242$class_depends),
		.class_depends=		_jc_java_nio_charset_CoderResult__242$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.java_nio_charset_CoderResult__24Cache= {
	    .get$edc027d4a510997f=
		&_jc_java_nio_charset_CoderResult__24Cache$method$get$edc027d4a510997f,
	    .make$f3cbfffb1f7afd3c=				// overridden
		&_jc_java_nio_charset_CoderResult__242$method$make$f3cbfffb1f7afd3c,
	},
	.java_nio_charset_CoderResult__242= {
	    .make$f3cbfffb1f7afd3c=
		&_jc_java_nio_charset_CoderResult__242$method$make$f3cbfffb1f7afd3c,
	},
    }
};
